#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Author: Ingelrest François (Athropos@gmail.com)
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA

import gettext, gobject, gtk, gtk.glade, modules, locale, os.path

from gui     import about
from tools   import consts, prefsManager
from gettext import gettext as _


def onResize(window, rectangle):
    """
        Save the new size of the window
    """
    prefsManager.set(__name__, 'win-width',  rectangle.width)
    prefsManager.set(__name__, 'win-height', rectangle.height)


# Localization
locale.setlocale(locale.LC_ALL, '')
gettext.textdomain(consts.appNameShort)
gettext.bindtextdomain(consts.appNameShort, consts.dirLocale)
gtk.glade.textdomain(consts.appNameShort)
gtk.glade.bindtextdomain(consts.appNameShort, consts.dirLocale)

# Create the GUI
wTree   = gtk.glade.XML(os.path.join(consts.dirRes, 'main.glade'), domain=consts.appNameShort)
mWindow = wTree.get_widget('win-main')

# Restore the previous state
mWindow.set_title(consts.appName)
mWindow.resize(prefsManager.get(__name__, 'win-width', 450), prefsManager.get(__name__, 'win-height', 480))

# Connect GTK handlers
wTree.signal_connect('onAbout',  lambda window: about.show(mWindow))
wTree.signal_connect('onQuit',   lambda window: modules.postQuitMsg())
wTree.signal_connect('onResize', onResize)

# Load all modules
# Calling threads_init() is needed to have other threads besides the main GTK one
gobject.threads_init()
modules.load(wTree)

# Here we go
modules.postMsg(modules.MSG_EVT_APP_STARTED)
mWindow.show_all()
gtk.main()
