# -*- coding: utf-8 -*-
#
# Author: Ingelrest François (Athropos@gmail.com)
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA

import mp3, ogg


# The format of the list returned by the readInfo() function
(
    INFO_FILENAME,
    INFO_TRACKNUMBER,
    INFO_TITLE,
    INFO_ARTIST,
    INFO_ALBUM,
    INFO_LENGTH
) = range(6)


def isSupported(file):
    """
        Return True if the given file has a supported format
    """
    return file.lower().endswith('.ogg') or file.lower().endswith('.mp3')


def getSupportedFormats():
    """
        Return a list of all formats from which tags can be extracted
        This list does not account for the installed gstreamer packages
    """
    return ['*.mp3', '*.ogg']


def readInfo(files):
    """
        Given a list of files, return a list such as:
        [[FILE1, TRACKNUMBER1, TITLE1, ARTIST1, ALBUM1, LENGTH1], [FILE2, TRACKNUMBER2, TITLE2, ARTIST2, ALBUM2, LENGTH2], ...]
    """
    info = []
    for file in files:
        if file.lower().endswith('.ogg'):
            info += [ogg.readInfo(file)]
        elif file.lower().endswith('.mp3'):
            info += [mp3.readInfo(file)]
        else:
            info += [[file, 0, '', '', '', 0]]
    return info
