# -*- coding: utf-8 -*-
#
# Author: Ingelrest François (Athropos@gmail.com)
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA


class Module:
    """
        This is the base class for all non-threaded modules
    """


    def __init__(self):
        """
            Constructor
        """
        pass


    def postMsg(self, msg, params):
        """
            Enqueue a new message
            Since this module is not threaded, handleMsg() is directly called
        """
        self.handleMsg(msg, params)


    def handleMsg(self, msg, params):
        """
            This function is called when a new message is available
            It should be overridden by subclasses
        """
        pass


    def join(self):
        """
            This function is used to wait for threaded modules to terminate
            For genericity, non-threaded modules need to have such function
        """
        pass


    def start(self):
        """
            This function is used to start threaded modules
            For genericity, non-threaded modules need to have such function
        """
        pass
