# -*- coding: utf-8 -*-
#
# Author: Ingelrest François (Athropos@gmail.com)
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA

import gtk, modules, pynotify, tools, tracklist

from tools                  import consts
from modules.threadedModule import ThreadedModule


class Notification(ThreadedModule):
    """
        This module displays information about the current track using the libnotify
    """


    def __init__(self, wTree):
        """
            Constructor
        """
        ThreadedModule.__init__(self)
        pynotify.init(consts.appNameShort)
        # Messages handled by this module
        modules.register(self, [modules.MSG_EVT_NEW_TRACK])


    def showNotification(self, trackInfo):
        """
            Show a notification
        """
        notifTitle = '%s  </b>[%s]<b>' % (trackInfo[tracklist.TITLE], tools.sec2str(trackInfo[tracklist.LENGTH]))
        notifBody  = 'by %s\nfrom %s' % (trackInfo[tracklist.ARTIST], trackInfo[tracklist.ALBUM])

        notif = pynotify.Notification(notifTitle, notifBody, gtk.STOCK_DIALOG_INFO)
        notif.set_timeout(10000)
        notif.show()


    # --== Message handler ==--


    def handleMsg(self, msg, params):
        """
            A message has been received
        """
        if msg == modules.MSG_EVT_NEW_TRACK:
            self.showNotification(params['trackInfo'])
