# -*- coding: utf-8 -*-
#
# Author: Ingelrest François (Athropos@gmail.com)
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA

import modules, tools

from gettext        import gettext as _
from modules.module import Module


class Statusbar(Module):
    """
        This module manages the status bar
    """


    def __init__(self, wTree):
        """
            Constructor
        """
        Module.__init__(self)
        self.statusbar = wTree.get_widget('statusbar')
        self.contextId = self.statusbar.get_context_id('tracklist info')
        # The tracklist is empty at first
        self.setTracklistInfo(0, 0)
        # Messages handled by this module
        modules.register(self, [modules.MSG_EVT_NEW_TRACKLIST])


    def setTracklistInfo(self, count, playtime):
        """
            Change the tracklist information
        """
        if count == 0:
            text = _('The tracklist is empty')
        elif count == 1:
            text = '%u %s  [%s]' % (count, _('track in playlist'), tools.sec2str(playtime))
        else:
            text = '%u %s  [%s]' % (count, _('tracks in playlist'), tools.sec2str(playtime))

        self.statusbar.pop(self.contextId)
        self.statusbar.push(self.contextId, text)


    # --== Message handler ==--


    def handleMsg(self, msg, params):
        """
            A message has been received
        """
        if msg == modules.MSG_EVT_NEW_TRACKLIST:
            self.setTracklistInfo(len(params['files']), params['playtime'])
