# -*- coding: utf-8 -*-
#
# Author: Ingelrest François (Athropos@gmail.com)
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA

import media, os.path


# Supported types
# 'bool' type must be placed *before* 'int' type, otherwise booleans are detected as integers
types = {bool : 'bool', int : 'int', str : 'str'}


def getType(value) :
    """
        Return the type of the value
    """
    for type in types.keys() :
        if isinstance(value, type) :
            return types[type]
    raise TypeError, str(value) + ' has an unsupported type'


def cast(value, type) :
    """
        Cast value from a string to the given type
    """
    if type == 'bool' :
        return value == 'True'
    elif type == 'int' :
        return int(value)
    elif type == 'str' :
        return str(value)
    raise TypeError, type + ' is an unsupported type'


def sec2str(duration):
    """
        Return a formatted string based on the given duration in seconds
    """
    hours    = duration / 3600
    duration = duration % 3600
    minutes  = duration / 60
    seconds  = duration % 60

    if hours != 0:
        return '%u:%02u:%02u' % (hours, minutes, seconds)
    return '%u:%02u' % (minutes, seconds)


def listMediaFiles(directory):
    """
        Return a list of all media files located in the given directory, None if any
    """
    mediaFiles = []
    if not os.path.isdir(directory):
        return None
    for filename in os.listdir(directory):
        file = os.path.join(directory, filename)
        if os.path.isfile(file) and media.isSupported(file):
            mediaFiles.append(file)
    if len(mediaFiles) == 0:
        return None
    return mediaFiles
