# -*- coding: utf-8 -*-
#
# Author: Ingelrest François (Athropos@gmail.com)
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA

import os, tools, xml.dom.ext, xml.dom.minidom

from tools import consts


# All preferences
mPrefs = {}


def save() :
    """
        Save all preferences to the disk
    """
    # Create the XML document
    doc  = xml.dom.minidom.Document()
    root = doc.createElement('prefs')
    root.setAttribute('version', str(consts.prefsVersion))
    doc.appendChild(root)
    # Write each preference to the document
    for prefName in mPrefs.keys() :
        node      = doc.createElement('pref')
        prefValue = mPrefs[prefName]
        node.setAttribute('name', prefName)
        node.setAttribute('value', str(prefValue))
        node.setAttribute('type', tools.getType(prefValue))
        root.appendChild(node)
    # Write the document to the disk
    file_object = open(consts.filePrefs, 'w')
    xml.dom.ext.PrettyPrint(doc, file_object)
    file_object.close()


def __set(name, value):
    """
        'Real' set function
    """
    mPrefs[name] = value;


def set(modName, prefName, prefValue) :
    """
        Change the value of a given preference
    """
    __set(modName + '_' + prefName, prefValue)


def get(modName, prefName, default=None) :
    """
        Retrieve the value of a given preference
    """
    if not mPrefs.has_key(modName + '_' + prefName) :
        return default
    return mPrefs[modName + '_' + prefName]


# Load saved preferences from the disk
if os.access(consts.filePrefs, os.F_OK) :
    root = xml.dom.minidom.parse(consts.filePrefs).documentElement
    # Don't parse a too old prefs file
    if root.hasAttribute('version') and int(root.getAttribute('version')) == consts.prefsVersion :
        for elt in root.getElementsByTagName('pref') :
            name  = elt.getAttribute('name')
            value = tools.cast(elt.getAttribute('value'), elt.getAttribute('type'))
            __set(name, value)
